# scripts
This directory is for convenience scripts that all Mephisto users may find useful. They should be runnable, polished, and have some kind of API or user interface, as opposed to being methods or modules like those present in the `tools` directory. 

Scripts in this directory should be grouped into folders by the abstractions or tasks they relate to.